@@ -382,7 +382,7 @@ class CheckboxSelectMultiple(forms.CheckboxSelectMultiple):
             attrs.update(extra_attrs)
         return attrs
 
-    def render(self, name, value, attrs=None, choices=()):
+    def render(self, name, value, attrs=None, choices=(), renderer=None):
         if value is None:
             value = []
         has_id = attrs and 'id' in attrs
